// %flair:license{
// This file is part of the Flair framework distributed under the
// CECILL-C License, Version 1.0.
// %flair:license}
/*!
 * \file ListWidget.h
 * \brief Class displaying a QListWidget on the ground station
 * \author Thomas Fuhrmann, Copyright Heudiasyc UMR UTC/CNRS 7253
 * \date 2016/07/26
 * \version 1.0
 */

#ifndef LISTWIDGET_H
#define LISTWIDGET_H

#include <Widget.h>

namespace flair {
namespace gui {

class LayoutPosition;

/*! \class ListWidget
*
* \brief Class displaying a QListWidget on the ground station
*
*/
class ListWidget : public Widget {
public:
  /*!
  * \brief Constructor
  *
  * Construct a QListWidget at given position.
  *
  * \param position position to display the QListWidget
  * \param name name
  */
  ListWidget(const LayoutPosition *position, std::string name);

  /*!
  * \brief Destructor
  *
  */
  ~ListWidget();

  /*!
 * \brief Add an item
 *
 * Add an item to the end of the list.
 *
 * \param name item nam
 */
  void AddItem(std::string name);

  /*!
  * \brief Remove an item
  *
  * Remove the currently selected item.
  */
  void RemoveItem(void);

private:
  /*!
  * \brief XmlEvent from ground station
  *
  * Reimplemented from Widget.
  *
  */
  void XmlEvent(void);
};

} // end namespace gui
} // end namespace flair

#endif // LISTWIDGET_H
